[Bf-blender-cvs] [c00d8fd] multiview: cleanup make all the "MV" todo notes into "XXX MV" for quick reference later

Dalai Felinto noreply at git.blender.org
Fri Aug 29 00:29:48 CEST 2014


Commit: c00d8fdb09dd572f266c3ca238e9e48442948d98
Author: Dalai Felinto
Date:   Thu Aug 28 11:58:43 2014 +0200
Branches: multiview
https://developer.blender.org/rBc00d8fdb09dd572f266c3ca238e9e48442948d98

cleanup make all the "MV" todo notes into "XXX MV" for quick reference later

===================================================================

M	release/scripts/startup/bl_ui/properties_render_layer.py
M	source/blender/compositor/nodes/COM_RenderLayersNode.cpp
M	source/blender/compositor/operations/COM_OutputFileMultiViewOperation.cpp
M	source/blender/makesrna/intern/rna_nodetree.c
M	source/blender/makesrna/intern/rna_render.c
M	source/blender/render/extern/include/RE_pipeline.h
M	source/blender/render/intern/source/pipeline.c
M	source/blender/render/intern/source/zbuf.c

===================================================================

diff --git a/release/scripts/startup/bl_ui/properties_render_layer.py b/release/scripts/startup/bl_ui/properties_render_layer.py
index 22fa423..a31275f 100644
--- a/release/scripts/startup/bl_ui/properties_render_layer.py
+++ b/release/scripts/startup/bl_ui/properties_render_layer.py
@@ -168,7 +168,7 @@ class RENDERLAYER_UL_renderviews(UIList):
         # assert(isinstance(item, bpy.types.SceneRenderView)
         view = item
         if self.layout_type in {'DEFAULT', 'COMPACT'}:
-            if view.name in ('left', 'right', 'Left', 'Right'): #MV remove left, right when I implement the ui names capitalized
+            if view.name in ('left', 'right', 'Left', 'Right'): #XXX MV remove left, right when I implement the ui names capitalized
                 layout.label(view.name, icon_value=icon + (not view.use))
             else:
                 layout.prop(view, "name", text="", index=index, icon_value=icon, emboss=False)
diff --git a/source/blender/compositor/nodes/COM_RenderLayersNode.cpp b/source/blender/compositor/nodes/COM_RenderLayersNode.cpp
index 7072070..642d719 100644
--- a/source/blender/compositor/nodes/COM_RenderLayersNode.cpp
+++ b/source/blender/compositor/nodes/COM_RenderLayersNode.cpp
@@ -39,7 +39,7 @@ void RenderLayersNode::testSocketLink(NodeConverter &converter, const Compositor
 	Scene *scene = (Scene *)this->getbNode()->id;
 	short layerId = this->getbNode()->custom1;
 
-	/* MV: we need a better place for this
+	/* XXX MV: we need a better place for this
 	 * (so says atmind/Jeroen Bakker),
 	 * but it will do for now. */
 	operation->setViewId(context.getViewId());
diff --git a/source/blender/compositor/operations/COM_OutputFileMultiViewOperation.cpp b/source/blender/compositor/operations/COM_OutputFileMultiViewOperation.cpp
index 1e34db4..5fac380 100644
--- a/source/blender/compositor/operations/COM_OutputFileMultiViewOperation.cpp
+++ b/source/blender/compositor/operations/COM_OutputFileMultiViewOperation.cpp
@@ -62,7 +62,7 @@ void *OutputOpenExrMultiViewOperation::get_handle(const char* filename)
 		exrhandle = IMB_exr_get_handle_name(filename);
 		if (this->m_actview > 0) return exrhandle;
 
-		/* MV are are doing very similar in
+		/* XXX MV are are doing very similar in
 		 * render_result.c::render_result_new
 		 * it could be an external shared function */
 
diff --git a/source/blender/makesrna/intern/rna_nodetree.c b/source/blender/makesrna/intern/rna_nodetree.c
index 1bb1e64..f688399 100644
--- a/source/blender/makesrna/intern/rna_nodetree.c
+++ b/source/blender/makesrna/intern/rna_nodetree.c
@@ -2626,7 +2626,7 @@ static int rna_Node_image_has_views_get(PointerRNA *ptr)
 	return views > 1;
 }
 
-#if 0 //MV we may not need that, I don't know yet
+#if 0 //XXX MV we may not need that, I don't know yet
 static void rna_Node_image_view_update(Main *bmain, Scene *scene, PointerRNA *ptr)
 {
 	bNode *node = (bNode *)ptr->data;
diff --git a/source/blender/makesrna/intern/rna_render.c b/source/blender/makesrna/intern/rna_render.c
index 2d35753..8345b50 100644
--- a/source/blender/makesrna/intern/rna_render.c
+++ b/source/blender/makesrna/intern/rna_render.c
@@ -352,6 +352,7 @@ static void rna_RenderLayer_passes_begin(CollectionPropertyIterator *iter, Point
 	rna_iterator_listbase_begin(iter, &rl->passes, NULL);
 }
 
+#if 0
 static int rna_RenderLayer_rect_get_length(PointerRNA *ptr, int length[RNA_MAX_ARRAY_DIMENSION])
 {
 	RenderLayer *rl = (RenderLayer *)ptr->data;
@@ -371,16 +372,17 @@ static void rna_RenderLayer_rect_get(PointerRNA *ptr, float *values)
 	 * or iterate via all Render and see which one contains given RenderLayer
 	 */
 
-	//MV 0 = actview
+	//XXX MV 0 = actview
 	float *rect = RE_RenderLayerGetPass(rl, SCE_PASS_COMBINED, 0);
 	memcpy(values, rect, sizeof(float) * rl->rectx * rl->recty * 4);
 }
+#endif
 
 void rna_RenderLayer_rect_set(PointerRNA *ptr, const float *values)
 {
 	RenderLayer *rl = (RenderLayer *)ptr->data;
 
-	//MV 0 = actview
+	//XXX MV 0 = actview
 	float *rect = RE_RenderLayerGetPass(rl, SCE_PASS_COMBINED, 0);
 
 	memcpy(rect, values, sizeof(float) * rl->rectx * rl->recty * 4);
@@ -725,7 +727,11 @@ static void rna_def_render_layer(BlenderRNA *brna)
 	                                  "rna_iterator_listbase_end", "rna_iterator_listbase_get",
 	                                  NULL, NULL, NULL, NULL);
 
-#if 0 //MV store actview in RL or pass as argument
+#if 0
+	/* XXX MV store actview in RL or pass as argument
+	 * Actually, as suggested by Brecht we should use string and not the int in the API
+	 * (same as we do for renderlayer)
+	 * */
 	prop = RNA_def_property(srna, "rect", PROP_FLOAT, PROP_NONE);
 	RNA_def_property_flag(prop, PROP_DYNAMIC);
 	RNA_def_property_multi_array(prop, 2, NULL);
diff --git a/source/blender/render/extern/include/RE_pipeline.h b/source/blender/render/extern/include/RE_pipeline.h
index e401830..b3ca226 100644
--- a/source/blender/render/extern/include/RE_pipeline.h
+++ b/source/blender/render/extern/include/RE_pipeline.h
@@ -91,7 +91,7 @@ typedef struct RenderPass {
 
 	char internal_name[64]; /* pass name without view */
 	char view[64];		/* amount defined in openexr_multi.h */
-	int view_id;	/* MV I don't think we need that */
+	int view_id;	/* XXX MV I don't think we need that */
 } RenderPass;
 
 /* a renderlayer is a full image, but with all passes and samples */
diff --git a/source/blender/render/intern/source/zbuf.c b/source/blender/render/intern/source/zbuf.c
index 1fd99a8..ab14c40 100644
--- a/source/blender/render/intern/source/zbuf.c
+++ b/source/blender/render/intern/source/zbuf.c
@@ -4059,7 +4059,7 @@ unsigned short *zbuffer_transp_shade(RenderPart *pa, RenderLayer *rl, float *pas
 	/* zero alpha pixels get speed vector max again */
 	if (addpassflag & SCE_PASS_VECTOR)
 		if (rl->layflag & SCE_LAY_SOLID) {
-			//MV probably never wants to use acolrect
+			//XXX MV probably never wants to use acolrect
 			float *rect = RE_RenderLayerGetPass(rl, SCE_PASS_COMBINED, R.actview);
 			reset_sky_speedvectors(pa, rl, rl->acolrect?rl->acolrect:rect);	/* if acolrect is set we use it */
 		}




More information about the Bf-blender-cvs mailing list
diff --git a/source/blender/render/intern/source/pipeline.c b/source/blender/render/intern/source/pipeline.c
index 3774efb..dbfba05 100644
--- a/source/blender/render/intern/source/pipeline.c
+++ b/source/blender/render/intern/source/pipeline.c
@@ -1363,7 +1363,7 @@ static void free_all_freestyle_renders(void);
 void RE_TileProcessor(Render *re)
 {
 	main_render_result_new(re);
-	threaded_tile_processor(re); //MV envmap could use multiview too, not implemented though
+	threaded_tile_processor(re); //XXX MV envmap could use multiview too, not implemented though
 	
 	re->i.lastframetime = PIL_check_seconds_timer() - re->i.starttime;
 	re->stats_draw(re->sdh, &re->i);
@@ -1610,7 +1610,7 @@ static void merge_renderresult_fields(RenderResult *rr, RenderResult *rr1, Rende
 		     rpass && rpass1 && rpass2;
 		     rpass = rpass->next, rpass1 = rpass1->next, rpass2 = rpass2->next)
 		{
 			//MV - it may work, I haven't tried though
 			interleave_rect(rr, rpass->rect, rpass1->rect, rpass2->rect, rpass->channels);
 		}
 	}
@@ -3365,7 +3365,7 @@ void RE_BlenderAnim(Render *re, Main *bmain, Scene *scene, Object *camera_overri
 		for (i = 0; i < totvideos; i++){
 			mh[i] = BKE_movie_handle_get(scene->r.im_format.imtype);
 
-			/*XXX MV need to come up with a solution for the name issue, because at the moment
+			/*XXX MV MOV need to come up with a solution for the name issue, because at the moment
 			 * it's handling the name entirely inside the movie format */
 			if (!mh[i]->start_movie(scene, &re->r, width, height, re->reports))
 				G.is_break = true;
@@ -3442,7 +3442,7 @@ void RE_BlenderAnim(Render *re, Main *bmain, Scene *scene, Object *camera_overri
 					continue;
 				}
 
-				/* XXX MV we should create/touch the multiview file or at least remove
+				/* XXX MV MOV we should create/touch the multiview file or at least remove
 				 * this dummy touched file after we are done creating the stereo pairs */
 				if (scene->r.mode & R_TOUCH && !BLI_exists(name)) {
 					BLI_make_existing_file(name); /* makes the dir if its not there */
@@ -3525,6 +3525,7 @@ void RE_PreviewRender(Render *re, Main *bmain, Scene *sce)
 	re->scene_color_manage = BKE_scene_check_color_management_enabled(sce);
 	re->lay = sce->lay;
 
+	/* XXX MV need to get the correct camera */
 	camera = RE_GetCamera(re);
 	RE_SetCamera(re, camera);
 
@@ -3587,12 +3588,18 @@ void RE_init_threadcount(Render *re)
 
 /* loads in image into a result, size must match
  * x/y offsets are only used on a partial copy when dimensions don't match */
+#if 1
+void RE_layer_load_from_file(RenderLayer *UNUSED(layer), ReportList *UNUSED(reports), const char *UNUSED(filename), int UNUSED(x), int UNUSED(y))
+{
+	/* XXX MV - not sure who is using this, I'll address later */
+	printf("%s\n", __func__);
+}
+#else
 void RE_layer_load_from_file(RenderLayer *layer, ReportList *reports, const char *filename, int x, int y)
 {
 	/* OCIO_TODO: assume layer was saved in defaule color space */
 	ImBuf *ibuf = IMB_loadiffname(filename, IB_rect, NULL);
 
-#if 0 //MV - not sure who is using this, I'll address later
 	if (ibuf && (ibuf->rect || ibuf->rect_float)) {
 		if (ibuf->x == layer->rectx && ibuf->y == layer->recty) {
 			if (ibuf->rect_float == NULL)
@@ -3628,8 +3635,8 @@ void RE_layer_load_from_file(RenderLayer *layer, ReportList *reports, const char
 	else {
 		BKE_reportf(reports, RPT_ERROR, "RE_result_rect_from_file: failed to load '%s'", filename);
 	}
-#endif
 }
+#endif
 
 void RE_result_load_from_file(RenderResult *result, ReportList *reports, const char *filename)
 {
@@ -1610,7 +1610,7 @@ static void merge_renderresult_fields(RenderResult *rr, RenderResult *rr1, Rende
 		     rpass = rpass->next, rpass1 = rpass1->next, rpass2 = rpass2->next)
 		{
-			//MV - it may work, I haven't tried though
+			//XXX MV - it may work, I haven't tried though
 			interleave_rect(rr, rpass->rect, rpass1->rect, rpass2->rect, rpass->channels);
 		}